# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ColorRange(Enum):
    UNSPECIFIED = "UNSPECIFIED"
    MPEG = "MPEG"
    JPEG = "JPEG"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class FileInputStreamType(Enum):
    TTML = "TTML"
    WEBVTT = "WEBVTT"
    SRT = "SRT"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.acl_permission import AclPermission
import pprint
import six


class AclEntry(object):
    @poscheck_model
    def __init__(self,
                 scope=None,
                 permission=None):
        # type: (string_types, AclPermission) -> None

        self._scope = None
        self._permission = None
        self.discriminator = None

        if scope is not None:
            self.scope = scope
        if permission is not None:
            self.permission = permission

    @property
    def openapi_types(self):
        types = {
            'scope': 'string_types',
            'permission': 'AclPermission'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'scope': 'scope',
            'permission': 'permission'
        }
        return attributes

    @property
    def scope(self):
        # type: () -> string_types
        """Gets the scope of this AclEntry.


        :return: The scope of this AclEntry.
        :rtype: string_types
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        # type: (string_types) -> None
        """Sets the scope of this AclEntry.


        :param scope: The scope of this AclEntry.
        :type: string_types
        """

        if scope is not None:
            if not isinstance(scope, string_types):
                raise TypeError("Invalid type for `scope`, type has to be `string_types`")

        self._scope = scope

    @property
    def permission(self):
        # type: () -> AclPermission
        """Gets the permission of this AclEntry.


        :return: The permission of this AclEntry.
        :rtype: AclPermission
        """
        return self._permission

    @permission.setter
    def permission(self, permission):
        # type: (AclPermission) -> None
        """Sets the permission of this AclEntry.


        :param permission: The permission of this AclEntry.
        :type: AclPermission
        """

        if permission is not None:
            if not isinstance(permission, AclPermission):
                raise TypeError("Invalid type for `permission`, type has to be `AclPermission`")

        self._permission = permission

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AclEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SmpteTimecodeFlavor(Enum):
    AUTO = "AUTO"
    NON_DROP_FRAME = "NON_DROP_FRAME"
    DROP_FRAME = "DROP_FRAME"



from bitmovin_api_sdk.encoding.inputs.zixi.zixi_api import ZixiApi
from bitmovin_api_sdk.encoding.inputs.zixi.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.zixi.zixi_input_list_query_params import ZixiInputListQueryParams



from bitmovin_api_sdk.encoding.encodings.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.encodings.live.insertable_content.insertable_content_api import InsertableContentApi
from bitmovin_api_sdk.encoding.encodings.live.scte35_cue.scte35_cue_api import Scte35CueApi



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.dolby_vision_metadata import DolbyVisionMetadata
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.streams.hdr.dolby_vision.dolby_vision_metadata_list_query_params import DolbyVisionMetadataListQueryParams


class DolbyVisionApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DolbyVisionApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, dolby_vision_metadata, **kwargs):
        # type: (string_types, string_types, DolbyVisionMetadata, dict) -> DolbyVisionMetadata
        """Add Dolby Vision Metadata

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param dolby_vision_metadata: The Dolby Vision Metadata to be added
        :type dolby_vision_metadata: DolbyVisionMetadata, required
        :return: Dolby Vision Metadata details
        :rtype: DolbyVisionMetadata
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/hdr/dolby-vision',
            dolby_vision_metadata,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=DolbyVisionMetadata,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, hdr_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Dolby Vision Metadata

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param hdr_id: Id of the Dolby Vision Metadata.
        :type hdr_id: string_types, required
        :return: Id of the Dolby Vision Metadata
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/hdr/dolby-vision/{hdr_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'hdr_id': hdr_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, hdr_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> DolbyVisionMetadata
        """Dolby Vision Metadata Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param hdr_id: Id of the Dolby Vision Metadata.
        :type hdr_id: string_types, required
        :return: Dolby Vision Metadata details
        :rtype: DolbyVisionMetadata
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/hdr/dolby-vision/{hdr_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'hdr_id': hdr_id},
            type=DolbyVisionMetadata,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, DolbyVisionMetadataListQueryParams, dict) -> DolbyVisionMetadata
        """List Dolby Vision Metadata

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DolbyVisionMetadataListQueryParams
        :return: List of Dolby Vision Metadata
        :rtype: DolbyVisionMetadata
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/hdr/dolby-vision',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=DolbyVisionMetadata,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.streams.thumbnails.thumbnails_api import ThumbnailsApi
from bitmovin_api_sdk.encoding.encodings.streams.thumbnails.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.thumbnails.thumbnail_list_query_params import ThumbnailListQueryParams



from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.fairplay.fairplay_api import FairplayApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.aes.aes_api import AesApi
from bitmovin_api_sdk.encoding.encodings.muxings.ts.drm.speke.speke_api import SpekeApi



from bitmovin_api_sdk.encoding.filters.filters_api import FiltersApi
from bitmovin_api_sdk.encoding.filters.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.filters.conform.conform_api import ConformApi
from bitmovin_api_sdk.encoding.filters.watermark.watermark_api import WatermarkApi
from bitmovin_api_sdk.encoding.filters.audio_volume.audio_volume_api import AudioVolumeApi
from bitmovin_api_sdk.encoding.filters.enhanced_watermark.enhanced_watermark_api import EnhancedWatermarkApi
from bitmovin_api_sdk.encoding.filters.crop.crop_api import CropApi
from bitmovin_api_sdk.encoding.filters.rotate.rotate_api import RotateApi
from bitmovin_api_sdk.encoding.filters.deinterlace.deinterlace_api import DeinterlaceApi
from bitmovin_api_sdk.encoding.filters.enhanced_deinterlace.enhanced_deinterlace_api import EnhancedDeinterlaceApi
from bitmovin_api_sdk.encoding.filters.audio_mix.audio_mix_api import AudioMixApi
from bitmovin_api_sdk.encoding.filters.denoise_hqdn3d.denoise_hqdn3d_api import DenoiseHqdn3dApi
from bitmovin_api_sdk.encoding.filters.ebu_r128_single_pass.ebu_r128_single_pass_api import EbuR128SinglePassApi
from bitmovin_api_sdk.encoding.filters.text.text_api import TextApi
from bitmovin_api_sdk.encoding.filters.interlace.interlace_api import InterlaceApi
from bitmovin_api_sdk.encoding.filters.unsharp.unsharp_api import UnsharpApi
from bitmovin_api_sdk.encoding.filters.scale.scale_api import ScaleApi
from bitmovin_api_sdk.encoding.filters.filter_list_query_params import FilterListQueryParams



from bitmovin_api_sdk.analytics.outputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.analytics.outputs.azure.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.analytics.outputs.azure.analytics_azure_output_list_query_params import AnalyticsAzureOutputListQueryParams



from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.dvb_teletext.dvb_teletext_api import DvbTeletextApi
from bitmovin_api_sdk.encoding.encodings.input_streams.subtitles.dvb_teletext.dvb_teletext_input_stream_list_query_params import DvbTeletextInputStreamListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.nex_guard_file_marker import NexGuardFileMarker
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.nexguard_file_marker.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.nexguard_file_marker.nex_guard_file_marker_list_query_params import NexGuardFileMarkerListQueryParams


class NexguardFileMarkerApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(NexguardFileMarkerApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, nex_guard_file_marker, **kwargs):
        # type: (string_types, string_types, NexGuardFileMarker, dict) -> NexGuardFileMarker
        """Add a nexguard file marker watermarking configurations

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param nex_guard_file_marker: The nexguard file marker configurations
        :type nex_guard_file_marker: NexGuardFileMarker, required
        :return: Nexguard file marker configurations details
        :rtype: NexGuardFileMarker
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/watermarking/nexguard-file-marker',
            nex_guard_file_marker,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=NexGuardFileMarker,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, nexguard_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete nexguard file marker watermarking configurations

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param nexguard_id: Id of the nexguard file marker watermarking configurations
        :type nexguard_id: string_types, required
        :return: Id of the nexguard file marker watermarking configurations.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/watermarking/nexguard-file-marker/{nexguard_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'nexguard_id': nexguard_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, nexguard_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> NexGuardFileMarker
        """Nexguard file marker watermarking configurations details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param nexguard_id: Id of the nexguard file marker watermarking configurations.
        :type nexguard_id: string_types, required
        :return: Nexguard file marker watermarking configurations details
        :rtype: NexGuardFileMarker
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/watermarking/nexguard-file-marker/{nexguard_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'nexguard_id': nexguard_id},
            type=NexGuardFileMarker,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, NexGuardFileMarkerListQueryParams, dict) -> NexGuardFileMarker
        """List nexguard file marker watermarking configurations

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: NexGuardFileMarkerListQueryParams
        :return: List of nexguard file marker watermarking configurations
        :rtype: NexGuardFileMarker
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/watermarking/nexguard-file-marker',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=NexGuardFileMarker,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.manifests_api import ManifestsApi
from bitmovin_api_sdk.encoding.manifests.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.dash_api import DashApi
from bitmovin_api_sdk.encoding.manifests.hls.hls_api import HlsApi
from bitmovin_api_sdk.encoding.manifests.smooth.smooth_api import SmoothApi
from bitmovin_api_sdk.encoding.manifests.manifest_list_query_params import ManifestListQueryParams



from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.cenc.cenc_api import CencApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.cenc.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.cenc.cenc_drm_list_query_params import CencDrmListQueryParams



from bitmovin_api_sdk.encoding.outputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.outputs.ftp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.ftp.ftp_output_list_query_params import FtpOutputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class SrtStatisticWindow(object):
    @poscheck_model
    def __init__(self,
                 congestion=None,
                 flight=None,
                 flow=None):
        # type: (int, int, int) -> None

        self._congestion = None
        self._flight = None
        self._flow = None
        self.discriminator = None

        if congestion is not None:
            self.congestion = congestion
        if flight is not None:
            self.flight = flight
        if flow is not None:
            self.flow = flow

    @property
    def openapi_types(self):
        types = {
            'congestion': 'int',
            'flight': 'int',
            'flow': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'congestion': 'congestion',
            'flight': 'flight',
            'flow': 'flow'
        }
        return attributes

    @property
    def congestion(self):
        # type: () -> int
        """Gets the congestion of this SrtStatisticWindow.


        :return: The congestion of this SrtStatisticWindow.
        :rtype: int
        """
        return self._congestion

    @congestion.setter
    def congestion(self, congestion):
        # type: (int) -> None
        """Sets the congestion of this SrtStatisticWindow.


        :param congestion: The congestion of this SrtStatisticWindow.
        :type: int
        """

        if congestion is not None:
            if not isinstance(congestion, int):
                raise TypeError("Invalid type for `congestion`, type has to be `int`")

        self._congestion = congestion

    @property
    def flight(self):
        # type: () -> int
        """Gets the flight of this SrtStatisticWindow.


        :return: The flight of this SrtStatisticWindow.
        :rtype: int
        """
        return self._flight

    @flight.setter
    def flight(self, flight):
        # type: (int) -> None
        """Sets the flight of this SrtStatisticWindow.


        :param flight: The flight of this SrtStatisticWindow.
        :type: int
        """

        if flight is not None:
            if not isinstance(flight, int):
                raise TypeError("Invalid type for `flight`, type has to be `int`")

        self._flight = flight

    @property
    def flow(self):
        # type: () -> int
        """Gets the flow of this SrtStatisticWindow.


        :return: The flow of this SrtStatisticWindow.
        :rtype: int
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        # type: (int) -> None
        """Sets the flow of this SrtStatisticWindow.


        :param flow: The flow of this SrtStatisticWindow.
        :type: int
        """

        if flow is not None:
            if not isinstance(flow, int):
                raise TypeError("Invalid type for `flow`, type has to be `int`")

        self._flow = flow

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SrtStatisticWindow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ProfileH264(Enum):
    BASELINE = "BASELINE"
    MAIN = "MAIN"
    HIGH = "HIGH"



from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.srt.burn_in_subtitle_srt_list_query_params import BurnInSubtitleSrtListQueryParams



# coding: utf-8


from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint


class DashRepresentation(BitmovinResponse):

    discriminator_value_class_map = {
        'DRM_FMP4': 'DashFmp4DrmRepresentation',
        'FMP4': 'DashFmp4Representation',
        'WEBM': 'DashWebmRepresentation',
        'CMAF': 'DashCmafRepresentation',
        'CHUNKED_TEXT': 'DashChunkedTextRepresentation',
        'MP4': 'DashMp4Representation',
        'DRM_MP4': 'DashMp4DrmRepresentation',
        'PROGRESSIVE_WEBM': 'DashProgressiveWebmRepresentation',
        'VTT': 'DashVttRepresentation',
        'SPRITE': 'SpriteRepresentation',
        'IMSC': 'DashImscRepresentation',
        'CONTENT_PROTECTION': 'ContentProtection'
    }

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DashRepresentation, self), "to_dict"):
            result = super(DashRepresentation, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['typeDiscriminator'] = k
                break
        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashRepresentation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ExternalIdMode(Enum):
    CUSTOM = "CUSTOM"
    GLOBAL = "GLOBAL"
    GENERATED = "GENERATED"



from bitmovin_api_sdk.encoding.configurations.video.h264.h264_api import H264Api
from bitmovin_api_sdk.encoding.configurations.video.h264.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.video.h264.h264_video_configuration_list_query_params import H264VideoConfigurationListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.muxing_type import MuxingType
import pprint
import six


class StatisticsPerMuxing(object):
    @poscheck_model
    def __init__(self,
                 stream_id=None,
                 muxing_id=None,
                 multiplicator=None,
                 encoded_bytes=None,
                 billable_minutes=None,
                 muxing_type=None):
        # type: (string_types, string_types, float, int, float, MuxingType) -> None

        self._stream_id = None
        self._muxing_id = None
        self._multiplicator = None
        self._encoded_bytes = None
        self._billable_minutes = None
        self._muxing_type = None
        self.discriminator = None

        if stream_id is not None:
            self.stream_id = stream_id
        if muxing_id is not None:
            self.muxing_id = muxing_id
        if multiplicator is not None:
            self.multiplicator = multiplicator
        if encoded_bytes is not None:
            self.encoded_bytes = encoded_bytes
        if billable_minutes is not None:
            self.billable_minutes = billable_minutes
        if muxing_type is not None:
            self.muxing_type = muxing_type

    @property
    def openapi_types(self):
        types = {
            'stream_id': 'string_types',
            'muxing_id': 'string_types',
            'multiplicator': 'float',
            'encoded_bytes': 'int',
            'billable_minutes': 'float',
            'muxing_type': 'MuxingType'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'stream_id': 'streamId',
            'muxing_id': 'muxingId',
            'multiplicator': 'multiplicator',
            'encoded_bytes': 'encodedBytes',
            'billable_minutes': 'billableMinutes',
            'muxing_type': 'muxingType'
        }
        return attributes

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this StatisticsPerMuxing.

        ID of the stream (required)

        :return: The stream_id of this StatisticsPerMuxing.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this StatisticsPerMuxing.

        ID of the stream (required)

        :param stream_id: The stream_id of this StatisticsPerMuxing.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def muxing_id(self):
        # type: () -> string_types
        """Gets the muxing_id of this StatisticsPerMuxing.

        ID of the muxing (required)

        :return: The muxing_id of this StatisticsPerMuxing.
        :rtype: string_types
        """
        return self._muxing_id

    @muxing_id.setter
    def muxing_id(self, muxing_id):
        # type: (string_types) -> None
        """Sets the muxing_id of this StatisticsPerMuxing.

        ID of the muxing (required)

        :param muxing_id: The muxing_id of this StatisticsPerMuxing.
        :type: string_types
        """

        if muxing_id is not None:
            if not isinstance(muxing_id, string_types):
                raise TypeError("Invalid type for `muxing_id`, type has to be `string_types`")

        self._muxing_id = muxing_id

    @property
    def multiplicator(self):
        # type: () -> float
        """Gets the multiplicator of this StatisticsPerMuxing.

        Multiplier for the encoded minutes. Depends on muxing type. (required)

        :return: The multiplicator of this StatisticsPerMuxing.
        :rtype: float
        """
        return self._multiplicator

    @multiplicator.setter
    def multiplicator(self, multiplicator):
        # type: (float) -> None
        """Sets the multiplicator of this StatisticsPerMuxing.

        Multiplier for the encoded minutes. Depends on muxing type. (required)

        :param multiplicator: The multiplicator of this StatisticsPerMuxing.
        :type: float
        """

        if multiplicator is not None:
            if not isinstance(multiplicator, (float, int)):
                raise TypeError("Invalid type for `multiplicator`, type has to be `float`")

        self._multiplicator = multiplicator

    @property
    def encoded_bytes(self):
        # type: () -> int
        """Gets the encoded_bytes of this StatisticsPerMuxing.

        Encoded bytes. (required)

        :return: The encoded_bytes of this StatisticsPerMuxing.
        :rtype: int
        """
        return self._encoded_bytes

    @encoded_bytes.setter
    def encoded_bytes(self, encoded_bytes):
        # type: (int) -> None
        """Sets the encoded_bytes of this StatisticsPerMuxing.

        Encoded bytes. (required)

        :param encoded_bytes: The encoded_bytes of this StatisticsPerMuxing.
        :type: int
        """

        if encoded_bytes is not None:
            if not isinstance(encoded_bytes, int):
                raise TypeError("Invalid type for `encoded_bytes`, type has to be `int`")

        self._encoded_bytes = encoded_bytes

    @property
    def billable_minutes(self):
        # type: () -> float
        """Gets the billable_minutes of this StatisticsPerMuxing.

        Resulting minutes you will be charged for. (required)

        :return: The billable_minutes of this StatisticsPerMuxing.
        :rtype: float
        """
        return self._billable_minutes

    @billable_minutes.setter
    def billable_minutes(self, billable_minutes):
        # type: (float) -> None
        """Sets the billable_minutes of this StatisticsPerMuxing.

        Resulting minutes you will be charged for. (required)

        :param billable_minutes: The billable_minutes of this StatisticsPerMuxing.
        :type: float
        """

        if billable_minutes is not None:
            if not isinstance(billable_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_minutes`, type has to be `float`")

        self._billable_minutes = billable_minutes

    @property
    def muxing_type(self):
        # type: () -> MuxingType
        """Gets the muxing_type of this StatisticsPerMuxing.


        :return: The muxing_type of this StatisticsPerMuxing.
        :rtype: MuxingType
        """
        return self._muxing_type

    @muxing_type.setter
    def muxing_type(self, muxing_type):
        # type: (MuxingType) -> None
        """Sets the muxing_type of this StatisticsPerMuxing.


        :param muxing_type: The muxing_type of this StatisticsPerMuxing.
        :type: MuxingType
        """

        if muxing_type is not None:
            if not isinstance(muxing_type, MuxingType):
                raise TypeError("Invalid type for `muxing_type`, type has to be `MuxingType`")

        self._muxing_type = muxing_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatisticsPerMuxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.statistics.cdn.usage.usage_api import UsageApi
from bitmovin_api_sdk.encoding.statistics.cdn.usage.cdn_usage_statistics_get_query_params import CdnUsageStatisticsGetQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class SimpleEncodingLiveCloudRegion(Enum):
    NORTH_AMERICA = "NORTH_AMERICA"
    SOUTH_AMERICA = "SOUTH_AMERICA"
    EUROPE = "EUROPE"
    AFRICA = "AFRICA"
    ASIA = "ASIA"
    AUSTRALIA = "AUSTRALIA"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.input_stream import InputStream
import pprint
import six


class H264PictureTimingTrimmingInputStream(InputStream):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 input_stream_id=None,
                 start_pic_timing=None,
                 end_pic_timing=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, string_types, string_types, string_types) -> None
        super(H264PictureTimingTrimmingInputStream, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._input_stream_id = None
        self._start_pic_timing = None
        self._end_pic_timing = None
        self.discriminator = None

        if input_stream_id is not None:
            self.input_stream_id = input_stream_id
        if start_pic_timing is not None:
            self.start_pic_timing = start_pic_timing
        if end_pic_timing is not None:
            self.end_pic_timing = end_pic_timing

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(H264PictureTimingTrimmingInputStream, self), 'openapi_types'):
            types = getattr(super(H264PictureTimingTrimmingInputStream, self), 'openapi_types')

        types.update({
            'input_stream_id': 'string_types',
            'start_pic_timing': 'string_types',
            'end_pic_timing': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(H264PictureTimingTrimmingInputStream, self), 'attribute_map'):
            attributes = getattr(super(H264PictureTimingTrimmingInputStream, self), 'attribute_map')

        attributes.update({
            'input_stream_id': 'inputStreamId',
            'start_pic_timing': 'startPicTiming',
            'end_pic_timing': 'endPicTiming'
        })
        return attributes

    @property
    def input_stream_id(self):
        # type: () -> string_types
        """Gets the input_stream_id of this H264PictureTimingTrimmingInputStream.

        The id of the ingest input stream that should be trimmed

        :return: The input_stream_id of this H264PictureTimingTrimmingInputStream.
        :rtype: string_types
        """
        return self._input_stream_id

    @input_stream_id.setter
    def input_stream_id(self, input_stream_id):
        # type: (string_types) -> None
        """Sets the input_stream_id of this H264PictureTimingTrimmingInputStream.

        The id of the ingest input stream that should be trimmed

        :param input_stream_id: The input_stream_id of this H264PictureTimingTrimmingInputStream.
        :type: string_types
        """

        if input_stream_id is not None:
            if not isinstance(input_stream_id, string_types):
                raise TypeError("Invalid type for `input_stream_id`, type has to be `string_types`")

        self._input_stream_id = input_stream_id

    @property
    def start_pic_timing(self):
        # type: () -> string_types
        """Gets the start_pic_timing of this H264PictureTimingTrimmingInputStream.

        Defines the H264 SEI picture timing, as specified in ISO/IEC 14496-10:2008, of the frame from which the encoding should start. The frame indicated by this value will be included in the encoding

        :return: The start_pic_timing of this H264PictureTimingTrimmingInputStream.
        :rtype: string_types
        """
        return self._start_pic_timing

    @start_pic_timing.setter
    def start_pic_timing(self, start_pic_timing):
        # type: (string_types) -> None
        """Sets the start_pic_timing of this H264PictureTimingTrimmingInputStream.

        Defines the H264 SEI picture timing, as specified in ISO/IEC 14496-10:2008, of the frame from which the encoding should start. The frame indicated by this value will be included in the encoding

        :param start_pic_timing: The start_pic_timing of this H264PictureTimingTrimmingInputStream.
        :type: string_types
        """

        if start_pic_timing is not None:
            if not isinstance(start_pic_timing, string_types):
                raise TypeError("Invalid type for `start_pic_timing`, type has to be `string_types`")

        self._start_pic_timing = start_pic_timing

    @property
    def end_pic_timing(self):
        # type: () -> string_types
        """Gets the end_pic_timing of this H264PictureTimingTrimmingInputStream.

        Defines the H264 SEI picture timing, as specified in ISO/IEC 14496-10:2008, of the frame at which the encoding should stop. The frame indicated by this value will be included in the encoding

        :return: The end_pic_timing of this H264PictureTimingTrimmingInputStream.
        :rtype: string_types
        """
        return self._end_pic_timing

    @end_pic_timing.setter
    def end_pic_timing(self, end_pic_timing):
        # type: (string_types) -> None
        """Sets the end_pic_timing of this H264PictureTimingTrimmingInputStream.

        Defines the H264 SEI picture timing, as specified in ISO/IEC 14496-10:2008, of the frame at which the encoding should stop. The frame indicated by this value will be included in the encoding

        :param end_pic_timing: The end_pic_timing of this H264PictureTimingTrimmingInputStream.
        :type: string_types
        """

        if end_pic_timing is not None:
            if not isinstance(end_pic_timing, string_types):
                raise TypeError("Invalid type for `end_pic_timing`, type has to be `string_types`")

        self._end_pic_timing = end_pic_timing

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(H264PictureTimingTrimmingInputStream, self), "to_dict"):
            result = super(H264PictureTimingTrimmingInputStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, H264PictureTimingTrimmingInputStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.custom_web_player_build_domain import CustomWebPlayerBuildDomain
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class DomainsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DomainsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, custom_web_player_build_domain, **kwargs):
        # type: (CustomWebPlayerBuildDomain, dict) -> CustomWebPlayerBuildDomain
        """Add Domain

        :param custom_web_player_build_domain: The Domain to be added
        :type custom_web_player_build_domain: CustomWebPlayerBuildDomain, required
        :return: Domain details
        :rtype: CustomWebPlayerBuildDomain
        """

        return self.api_client.post(
            '/player/custom-builds/web/domains',
            custom_web_player_build_domain,
            type=CustomWebPlayerBuildDomain,
            **kwargs
        )

    def delete(self, domain_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Domain

        :param domain_id: Id of the domain
        :type domain_id: string_types, required
        :return: Id of the domain
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/player/custom-builds/web/domains/{domain_id}',
            path_params={'domain_id': domain_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, domain_id, **kwargs):
        # type: (string_types, dict) -> CustomWebPlayerBuildDomain
        """Get Domain Details

        :param domain_id: Id of the domain
        :type domain_id: string_types, required
        :return: Id of the domain
        :rtype: CustomWebPlayerBuildDomain
        """

        return self.api_client.get(
            '/player/custom-builds/web/domains/{domain_id}',
            path_params={'domain_id': domain_id},
            type=CustomWebPlayerBuildDomain,
            **kwargs
        )

    def list(self, **kwargs):
        # type: (dict) -> CustomWebPlayerBuildDomain
        """List Domain Details

        :return: List of domain details
        :rtype: CustomWebPlayerBuildDomain
        """

        return self.api_client.get(
            '/player/custom-builds/web/domains',
            pagination_response=True,
            type=CustomWebPlayerBuildDomain,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.input_streams.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.input_streams.captions.cea608.cea608_api import Cea608Api
from bitmovin_api_sdk.encoding.encodings.input_streams.captions.cea708.cea708_api import Cea708Api



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class AdaptationSet(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 custom_attributes=None,
                 roles=None,
                 accessibilities=None,
                 labels=None):
        # type: (string_types, list[CustomAttribute], list[AdaptationSetRole], list[Accessibility], list[Label]) -> None
        super(AdaptationSet, self).__init__(id_=id_)

        self._custom_attributes = list()
        self._roles = list()
        self._accessibilities = list()
        self._labels = list()
        self.discriminator = 'type'

        if custom_attributes is not None:
            self.custom_attributes = custom_attributes
        if roles is not None:
            self.roles = roles
        if accessibilities is not None:
            self.accessibilities = accessibilities
        if labels is not None:
            self.labels = labels

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(AdaptationSet, self), 'openapi_types'):
            types = getattr(super(AdaptationSet, self), 'openapi_types')

        types.update({
            'custom_attributes': 'list[CustomAttribute]',
            'roles': 'list[AdaptationSetRole]',
            'accessibilities': 'list[Accessibility]',
            'labels': 'list[Label]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(AdaptationSet, self), 'attribute_map'):
            attributes = getattr(super(AdaptationSet, self), 'attribute_map')

        attributes.update({
            'custom_attributes': 'customAttributes',
            'roles': 'roles',
            'accessibilities': 'accessibilities',
            'labels': 'labels'
        })
        return attributes

    discriminator_value_class_map = {
        'VIDEO': 'VideoAdaptationSet',
        'AUDIO': 'AudioAdaptationSet',
        'IMAGE': 'ImageAdaptationSet',
        'SUBTITLE': 'SubtitleAdaptationSet'
    }

    @property
    def custom_attributes(self):
        # type: () -> list[CustomAttribute]
        """Gets the custom_attributes of this AdaptationSet.

        Custom adaptation set attributes

        :return: The custom_attributes of this AdaptationSet.
        :rtype: list[CustomAttribute]
        """
        return self._custom_attributes

    @custom_attributes.setter
    def custom_attributes(self, custom_attributes):
        # type: (list) -> None
        """Sets the custom_attributes of this AdaptationSet.

        Custom adaptation set attributes

        :param custom_attributes: The custom_attributes of this AdaptationSet.
        :type: list[CustomAttribute]
        """

        if custom_attributes is not None:
            if not isinstance(custom_attributes, list):
                raise TypeError("Invalid type for `custom_attributes`, type has to be `list[CustomAttribute]`")

        self._custom_attributes = custom_attributes

    @property
    def roles(self):
        # type: () -> list[AdaptationSetRole]
        """Gets the roles of this AdaptationSet.

        Roles of the adaptation set

        :return: The roles of this AdaptationSet.
        :rtype: list[AdaptationSetRole]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        # type: (list) -> None
        """Sets the roles of this AdaptationSet.

        Roles of the adaptation set

        :param roles: The roles of this AdaptationSet.
        :type: list[AdaptationSetRole]
        """

        if roles is not None:
            if not isinstance(roles, list):
                raise TypeError("Invalid type for `roles`, type has to be `list[AdaptationSetRole]`")

        self._roles = roles

    @property
    def accessibilities(self):
        # type: () -> list[Accessibility]
        """Gets the accessibilities of this AdaptationSet.

        Provide signaling of CEA 607 and CEA 708

        :return: The accessibilities of this AdaptationSet.
        :rtype: list[Accessibility]
        """
        return self._accessibilities

    @accessibilities.setter
    def accessibilities(self, accessibilities):
        # type: (list) -> None
        """Sets the accessibilities of this AdaptationSet.

        Provide signaling of CEA 607 and CEA 708

        :param accessibilities: The accessibilities of this AdaptationSet.
        :type: list[Accessibility]
        """

        if accessibilities is not None:
            if not isinstance(accessibilities, list):
                raise TypeError("Invalid type for `accessibilities`, type has to be `list[Accessibility]`")

        self._accessibilities = accessibilities

    @property
    def labels(self):
        # type: () -> list[Label]
        """Gets the labels of this AdaptationSet.

        List of labels

        :return: The labels of this AdaptationSet.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        # type: (list) -> None
        """Sets the labels of this AdaptationSet.

        List of labels

        :param labels: The labels of this AdaptationSet.
        :type: list[Label]
        """

        if labels is not None:
            if not isinstance(labels, list):
                raise TypeError("Invalid type for `labels`, type has to be `list[Label]`")

        self._labels = labels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(AdaptationSet, self), "to_dict"):
            result = super(AdaptationSet, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['type'] = k
                break
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdaptationSet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.adaptation_set import AdaptationSet
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.subtitle.subtitle_api import SubtitleApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.image.image_api import ImageApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.representations.representations_api import RepresentationsApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.contentprotection.contentprotection_api import ContentprotectionApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.adaptationsets.adaptation_set_list_query_params import AdaptationSetListQueryParams


class AdaptationsetsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(AdaptationsetsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.audio = AudioApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.video = VideoApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.subtitle = SubtitleApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.image = ImageApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.representations = RepresentationsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.contentprotection = ContentprotectionApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def list(self, manifest_id, period_id, query_params=None, **kwargs):
        # type: (string_types, string_types, AdaptationSetListQueryParams, dict) -> AdaptationSet
        """List all AdaptationSets

        :param manifest_id: Id of the Manifest
        :type manifest_id: string_types, required
        :param period_id: Id of the Period
        :type period_id: string_types, required
        :param query_params: Query parameters
        :type query_params: AdaptationSetListQueryParams
        :return: AdaptationSets of the Period
        :rtype: AdaptationSet
        """

        return self.api_client.get(
            '/encoding/manifests/dash/{manifest_id}/periods/{period_id}/adaptationsets',
            path_params={'manifest_id': manifest_id, 'period_id': period_id},
            query_params=query_params,
            pagination_response=True,
            type=AdaptationSet,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ScheduledInsertableContentStatus(Enum):
    CREATED = "CREATED"
    SCHEDULED = "SCHEDULED"
    TO_BE_DESCHEDULED = "TO_BE_DESCHEDULED"
    DESCHEDULED = "DESCHEDULED"
    ERROR = "ERROR"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.speke_drm import SpekeDrm
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.drm.speke.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_ts.drm.speke.speke_drm_list_query_params import SpekeDrmListQueryParams


class SpekeApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SpekeApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, muxing_id, speke_drm, **kwargs):
        # type: (string_types, string_types, SpekeDrm, dict) -> SpekeDrm
        """Add SPEKE DRM key provider to Progressive TS

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param speke_drm: The SPEKE DRM key provider to be created
        :type speke_drm: SpekeDrm, required
        :return: SPEKE DRM key provider
        :rtype: SpekeDrm
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/drm/speke',
            speke_drm,
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=SpekeDrm,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete SPEKE DRM from a Progressive TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param drm_id: Id of the SPEKE DRM.
        :type drm_id: string_types, required
        :return: Id of the SPEKE DRM
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/drm/speke/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> SpekeDrm
        """SPEKE DRM Details of a Progressive TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param drm_id: Id of the SPEKE DRM.
        :type drm_id: string_types, required
        :return: SPEKE DRM
        :rtype: SpekeDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/drm/speke/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=SpekeDrm,
            **kwargs
        )

    def list(self, encoding_id, muxing_id, query_params=None, **kwargs):
        # type: (string_types, string_types, SpekeDrmListQueryParams, dict) -> SpekeDrm
        """List SPEKE DRM of a Progressive TS muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the Progressive TS muxing
        :type muxing_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SpekeDrmListQueryParams
        :return: List of SPEKE DRM key provider
        :rtype: SpekeDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/progressive-ts/{muxing_id}/drm/speke',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            query_params=query_params,
            pagination_response=True,
            type=SpekeDrm,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.marlin.marlin_api import MarlinApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.marlin.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.marlin.marlin_drm_list_query_params import MarlinDrmListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.codec_configuration import CodecConfiguration
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.configurations.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.configurations.video.video_api import VideoApi
from bitmovin_api_sdk.encoding.configurations.audio.audio_api import AudioApi
from bitmovin_api_sdk.encoding.configurations.subtitles.subtitles_api import SubtitlesApi
from bitmovin_api_sdk.encoding.configurations.codec_configuration_list_query_params import CodecConfigurationListQueryParams


class ConfigurationsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ConfigurationsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.type = TypeApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.video = VideoApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.audio = AudioApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.subtitles = SubtitlesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> CodecConfiguration
        """Get Codec Configuration Details

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: Codec Configuration details
        :rtype: CodecConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations/{configuration_id}',
            path_params={'configuration_id': configuration_id},
            type=CodecConfiguration,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (CodecConfigurationListQueryParams, dict) -> CodecConfiguration
        """List all Codec Configurations

        :param query_params: Query parameters
        :type query_params: CodecConfigurationListQueryParams
        :return: List of codec configurations with type information
        :rtype: CodecConfiguration
        """

        return self.api_client.get(
            '/encoding/configurations',
            query_params=query_params,
            pagination_response=True,
            type=CodecConfiguration,
            **kwargs
        )



from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.packed_audio_api import PackedAudioApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.drm.drm_api import DrmApi
from bitmovin_api_sdk.encoding.encodings.muxings.packed_audio.packed_audio_muxing_list_query_params import PackedAudioMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.deinterlace_auto_enable import DeinterlaceAutoEnable
from bitmovin_api_sdk.models.deinterlace_frame_selection_mode import DeinterlaceFrameSelectionMode
from bitmovin_api_sdk.models.deinterlace_mode import DeinterlaceMode
from bitmovin_api_sdk.models.filter import Filter
from bitmovin_api_sdk.models.picture_field_parity import PictureFieldParity
import pprint
import six


class DeinterlaceFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 parity=None,
                 mode=None,
                 frame_selection_mode=None,
                 auto_enable=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, PictureFieldParity, DeinterlaceMode, DeinterlaceFrameSelectionMode, DeinterlaceAutoEnable) -> None
        super(DeinterlaceFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._parity = None
        self._mode = None
        self._frame_selection_mode = None
        self._auto_enable = None
        self.discriminator = None

        if parity is not None:
            self.parity = parity
        if mode is not None:
            self.mode = mode
        if frame_selection_mode is not None:
            self.frame_selection_mode = frame_selection_mode
        if auto_enable is not None:
            self.auto_enable = auto_enable

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DeinterlaceFilter, self), 'openapi_types'):
            types = getattr(super(DeinterlaceFilter, self), 'openapi_types')

        types.update({
            'parity': 'PictureFieldParity',
            'mode': 'DeinterlaceMode',
            'frame_selection_mode': 'DeinterlaceFrameSelectionMode',
            'auto_enable': 'DeinterlaceAutoEnable'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DeinterlaceFilter, self), 'attribute_map'):
            attributes = getattr(super(DeinterlaceFilter, self), 'attribute_map')

        attributes.update({
            'parity': 'parity',
            'mode': 'mode',
            'frame_selection_mode': 'frameSelectionMode',
            'auto_enable': 'autoEnable'
        })
        return attributes

    @property
    def parity(self):
        # type: () -> PictureFieldParity
        """Gets the parity of this DeinterlaceFilter.


        :return: The parity of this DeinterlaceFilter.
        :rtype: PictureFieldParity
        """
        return self._parity

    @parity.setter
    def parity(self, parity):
        # type: (PictureFieldParity) -> None
        """Sets the parity of this DeinterlaceFilter.


        :param parity: The parity of this DeinterlaceFilter.
        :type: PictureFieldParity
        """

        if parity is not None:
            if not isinstance(parity, PictureFieldParity):
                raise TypeError("Invalid type for `parity`, type has to be `PictureFieldParity`")

        self._parity = parity

    @property
    def mode(self):
        # type: () -> DeinterlaceMode
        """Gets the mode of this DeinterlaceFilter.


        :return: The mode of this DeinterlaceFilter.
        :rtype: DeinterlaceMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        # type: (DeinterlaceMode) -> None
        """Sets the mode of this DeinterlaceFilter.


        :param mode: The mode of this DeinterlaceFilter.
        :type: DeinterlaceMode
        """

        if mode is not None:
            if not isinstance(mode, DeinterlaceMode):
                raise TypeError("Invalid type for `mode`, type has to be `DeinterlaceMode`")

        self._mode = mode

    @property
    def frame_selection_mode(self):
        # type: () -> DeinterlaceFrameSelectionMode
        """Gets the frame_selection_mode of this DeinterlaceFilter.


        :return: The frame_selection_mode of this DeinterlaceFilter.
        :rtype: DeinterlaceFrameSelectionMode
        """
        return self._frame_selection_mode

    @frame_selection_mode.setter
    def frame_selection_mode(self, frame_selection_mode):
        # type: (DeinterlaceFrameSelectionMode) -> None
        """Sets the frame_selection_mode of this DeinterlaceFilter.


        :param frame_selection_mode: The frame_selection_mode of this DeinterlaceFilter.
        :type: DeinterlaceFrameSelectionMode
        """

        if frame_selection_mode is not None:
            if not isinstance(frame_selection_mode, DeinterlaceFrameSelectionMode):
                raise TypeError("Invalid type for `frame_selection_mode`, type has to be `DeinterlaceFrameSelectionMode`")

        self._frame_selection_mode = frame_selection_mode

    @property
    def auto_enable(self):
        # type: () -> DeinterlaceAutoEnable
        """Gets the auto_enable of this DeinterlaceFilter.


        :return: The auto_enable of this DeinterlaceFilter.
        :rtype: DeinterlaceAutoEnable
        """
        return self._auto_enable

    @auto_enable.setter
    def auto_enable(self, auto_enable):
        # type: (DeinterlaceAutoEnable) -> None
        """Sets the auto_enable of this DeinterlaceFilter.


        :param auto_enable: The auto_enable of this DeinterlaceFilter.
        :type: DeinterlaceAutoEnable
        """

        if auto_enable is not None:
            if not isinstance(auto_enable, DeinterlaceAutoEnable):
                raise TypeError("Invalid type for `auto_enable`, type has to be `DeinterlaceAutoEnable`")

        self._auto_enable = auto_enable

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DeinterlaceFilter, self), "to_dict"):
            result = super(DeinterlaceFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeinterlaceFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.account.account_api import AccountApi
from bitmovin_api_sdk.account.information.information_api import InformationApi
from bitmovin_api_sdk.account.api_keys.api_keys_api import ApiKeysApi
from bitmovin_api_sdk.account.organizations.organizations_api import OrganizationsApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsOrder(Enum):
    ASC = "ASC"
    DESC = "DESC"



from bitmovin_api_sdk.encoding.outputs.outputs_api import OutputsApi
from bitmovin_api_sdk.encoding.outputs.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.outputs.s3.s3_api import S3Api
from bitmovin_api_sdk.encoding.outputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.encoding.outputs.generic_s3.generic_s3_api import GenericS3Api
from bitmovin_api_sdk.encoding.outputs.local.local_api import LocalApi
from bitmovin_api_sdk.encoding.outputs.gcs.gcs_api import GcsApi
from bitmovin_api_sdk.encoding.outputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
from bitmovin_api_sdk.encoding.outputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.outputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.outputs.sftp.sftp_api import SftpApi
from bitmovin_api_sdk.encoding.outputs.akamai_msl.akamai_msl_api import AkamaiMslApi
from bitmovin_api_sdk.encoding.outputs.akamai_netstorage.akamai_netstorage_api import AkamaiNetstorageApi
from bitmovin_api_sdk.encoding.outputs.live_media_ingest.live_media_ingest_api import LiveMediaIngestApi
from bitmovin_api_sdk.encoding.outputs.cdn.cdn_api import CdnApi
from bitmovin_api_sdk.encoding.outputs.output_list_query_params import OutputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.play_ready_drm import PlayReadyDrm
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.playready.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.mp4.drm.playready.play_ready_drm_list_query_params import PlayReadyDrmListQueryParams


class PlayreadyApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(PlayreadyApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, muxing_id, play_ready_drm, **kwargs):
        # type: (string_types, string_types, PlayReadyDrm, dict) -> PlayReadyDrm
        """Add PlayReady DRM to an MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing.
        :type muxing_id: string_types, required
        :param play_ready_drm: The PlayReady DRM to be created
        :type play_ready_drm: PlayReadyDrm, required
        :return: PlayReady configuration
        :rtype: PlayReadyDrm
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}/drm/playready',
            play_ready_drm,
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            type=PlayReadyDrm,
            **kwargs
        )

    def delete(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete PlayReady DRM from an MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing.
        :type muxing_id: string_types, required
        :param drm_id: Id of the PlayReady DRM configuration.
        :type drm_id: string_types, required
        :return: Id of the PlayReady DRM configuration.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}/drm/playready/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, muxing_id, drm_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> PlayReadyDrm
        """PlayReady DRM Details of an MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing.
        :type muxing_id: string_types, required
        :param drm_id: Id of the PlayReady DRM configuration.
        :type drm_id: string_types, required
        :return: PlayReady configuration
        :rtype: PlayReadyDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}/drm/playready/{drm_id}',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id, 'drm_id': drm_id},
            type=PlayReadyDrm,
            **kwargs
        )

    def list(self, encoding_id, muxing_id, query_params=None, **kwargs):
        # type: (string_types, string_types, PlayReadyDrmListQueryParams, dict) -> PlayReadyDrm
        """List PlayReady DRMs of an MP4 muxing

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param muxing_id: Id of the MP4 muxing.
        :type muxing_id: string_types, required
        :param query_params: Query parameters
        :type query_params: PlayReadyDrmListQueryParams
        :return: List of PlayReady DRM configurations
        :rtype: PlayReadyDrm
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/muxings/mp4/{muxing_id}/drm/playready',
            path_params={'encoding_id': encoding_id, 'muxing_id': muxing_id},
            query_params=query_params,
            pagination_response=True,
            type=PlayReadyDrm,
            **kwargs
        )



from bitmovin_api_sdk.encoding.infrastructure.gce.gce_api import GceApi
from bitmovin_api_sdk.encoding.infrastructure.gce.regions.regions_api import RegionsApi
from bitmovin_api_sdk.encoding.infrastructure.gce.gce_account_list_query_params import GceAccountListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.aws_cloud_region import AwsCloudRegion
from bitmovin_api_sdk.models.external_id_mode import ExternalIdMode
from bitmovin_api_sdk.models.output import Output
from bitmovin_api_sdk.models.s3_signature_version import S3SignatureVersion
import pprint
import six


class S3RoleBasedOutput(Output):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 acl=None,
                 bucket_name=None,
                 role_arn=None,
                 external_id=None,
                 external_id_mode=None,
                 md5_meta_tag=None,
                 cloud_region=None,
                 signature_version=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[AclEntry], string_types, string_types, string_types, ExternalIdMode, string_types, AwsCloudRegion, S3SignatureVersion) -> None
        super(S3RoleBasedOutput, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, acl=acl)

        self._bucket_name = None
        self._role_arn = None
        self._external_id = None
        self._external_id_mode = None
        self._md5_meta_tag = None
        self._cloud_region = None
        self._signature_version = None
        self.discriminator = None

        if bucket_name is not None:
            self.bucket_name = bucket_name
        if role_arn is not None:
            self.role_arn = role_arn
        if external_id is not None:
            self.external_id = external_id
        if external_id_mode is not None:
            self.external_id_mode = external_id_mode
        if md5_meta_tag is not None:
            self.md5_meta_tag = md5_meta_tag
        if cloud_region is not None:
            self.cloud_region = cloud_region
        if signature_version is not None:
            self.signature_version = signature_version

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(S3RoleBasedOutput, self), 'openapi_types'):
            types = getattr(super(S3RoleBasedOutput, self), 'openapi_types')

        types.update({
            'bucket_name': 'string_types',
            'role_arn': 'string_types',
            'external_id': 'string_types',
            'external_id_mode': 'ExternalIdMode',
            'md5_meta_tag': 'string_types',
            'cloud_region': 'AwsCloudRegion',
            'signature_version': 'S3SignatureVersion'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(S3RoleBasedOutput, self), 'attribute_map'):
            attributes = getattr(super(S3RoleBasedOutput, self), 'attribute_map')

        attributes.update({
            'bucket_name': 'bucketName',
            'role_arn': 'roleArn',
            'external_id': 'externalId',
            'external_id_mode': 'externalIdMode',
            'md5_meta_tag': 'md5MetaTag',
            'cloud_region': 'cloudRegion',
            'signature_version': 'signatureVersion'
        })
        return attributes

    @property
    def bucket_name(self):
        # type: () -> string_types
        """Gets the bucket_name of this S3RoleBasedOutput.

        Amazon S3 bucket name (required)

        :return: The bucket_name of this S3RoleBasedOutput.
        :rtype: string_types
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        # type: (string_types) -> None
        """Sets the bucket_name of this S3RoleBasedOutput.

        Amazon S3 bucket name (required)

        :param bucket_name: The bucket_name of this S3RoleBasedOutput.
        :type: string_types
        """

        if bucket_name is not None:
            if not isinstance(bucket_name, string_types):
                raise TypeError("Invalid type for `bucket_name`, type has to be `string_types`")

        self._bucket_name = bucket_name

    @property
    def role_arn(self):
        # type: () -> string_types
        """Gets the role_arn of this S3RoleBasedOutput.

        Amazon ARN of the IAM Role (Identity and Access Management Role) that will be assumed for S3 access.  This role has to be created by the owner of the account with the S3 bucket (i.e., you as a customer). For Bitmovin to be able to assume this role, the following has to be added to the trust policy of the role:  ``` {   \"Effect\": \"Allow\",   \"Principal\": {     \"AWS\": \"arn:aws:iam::630681592166:user/bitmovinCustomerS3Access\"   },   \"Action\": \"sts:AssumeRole\",   \"Condition\": {     \"StringEquals\": {       \"sts:ExternalId\": \"{{externalId}}\"     }   } } ```  where \"arn:aws:iam::630681592166:user/bitmovinCustomerS3Access\" is the Bitmovin user used for the access. The `Condition` is optional but we highly recommend it, see property `externalId` below for more information.  This setup allows Bitmovin assume the provided IAM role and to write data to your S3 bucket. Please note that the IAM role has to have write access to S3.  For more information about role creation please visit https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-service.html#roles-creatingrole-service-console (required)

        :return: The role_arn of this S3RoleBasedOutput.
        :rtype: string_types
        """
        return self._role_arn

    @role_arn.setter
    def role_arn(self, role_arn):
        # type: (string_types) -> None
        """Sets the role_arn of this S3RoleBasedOutput.

        Amazon ARN of the IAM Role (Identity and Access Management Role) that will be assumed for S3 access.  This role has to be created by the owner of the account with the S3 bucket (i.e., you as a customer). For Bitmovin to be able to assume this role, the following has to be added to the trust policy of the role:  ``` {   \"Effect\": \"Allow\",   \"Principal\": {     \"AWS\": \"arn:aws:iam::630681592166:user/bitmovinCustomerS3Access\"   },   \"Action\": \"sts:AssumeRole\",   \"Condition\": {     \"StringEquals\": {       \"sts:ExternalId\": \"{{externalId}}\"     }   } } ```  where \"arn:aws:iam::630681592166:user/bitmovinCustomerS3Access\" is the Bitmovin user used for the access. The `Condition` is optional but we highly recommend it, see property `externalId` below for more information.  This setup allows Bitmovin assume the provided IAM role and to write data to your S3 bucket. Please note that the IAM role has to have write access to S3.  For more information about role creation please visit https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-service.html#roles-creatingrole-service-console (required)

        :param role_arn: The role_arn of this S3RoleBasedOutput.
        :type: string_types
        """

        if role_arn is not None:
            if not isinstance(role_arn, string_types):
                raise TypeError("Invalid type for `role_arn`, type has to be `string_types`")

        self._role_arn = role_arn

    @property
    def external_id(self):
        # type: () -> string_types
        """Gets the external_id of this S3RoleBasedOutput.

        External ID used together with the IAM role identified by `roleArn` to assume S3 access.  This ID is provided by the API if `externalIdMode` is set to `GLOBAL` or `GENERATED`. If present, it has to be added to the trust policy of the IAM role `roleArn` configured above, otherwise the API won't be able to write to the S3 bucket. An appropriate trust policy would look like this:  ``` {   \"Effect\": \"Allow\",   \"Principal\": {     \"AWS\": \"arn:aws:iam::630681592166:user/bitmovinCustomerS3Access\"   },   \"Action\": \"sts:AssumeRole\",   \"Condition\": {     \"StringEquals\": {       \"sts:ExternalId\": \"{{externalId}}\"     }   } } ```  where \"{{externalId}}\" is the generated ID.  This property is optional but we recommend it as an additional security feature. We will use both the `roleArn` and the `externalId` to access your S3 data. If the Amazon IAM role has an external ID configured but it is not provided in the output configuration Bitmovin won't be able to write to the S3 bucket. Also if the external ID does not match the one configured for the IAM role on AWS side, Bitmovin won't be able to access the S3 bucket.  If you need to change the external ID that is used by your IAM role, you need to create a new output, and use the external ID provided by the API to update your IAM role.  For more information please visit https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html 

        :return: The external_id of this S3RoleBasedOutput.
        :rtype: string_types
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        # type: (string_types) -> None
        """Sets the external_id of this S3RoleBasedOutput.

        External ID used together with the IAM role identified by `roleArn` to assume S3 access.  This ID is provided by the API if `externalIdMode` is set to `GLOBAL` or `GENERATED`. If present, it has to be added to the trust policy of the IAM role `roleArn` configured above, otherwise the API won't be able to write to the S3 bucket. An appropriate trust policy would look like this:  ``` {   \"Effect\": \"Allow\",   \"Principal\": {     \"AWS\": \"arn:aws:iam::630681592166:user/bitmovinCustomerS3Access\"   },   \"Action\": \"sts:AssumeRole\",   \"Condition\": {     \"StringEquals\": {       \"sts:ExternalId\": \"{{externalId}}\"     }   } } ```  where \"{{externalId}}\" is the generated ID.  This property is optional but we recommend it as an additional security feature. We will use both the `roleArn` and the `externalId` to access your S3 data. If the Amazon IAM role has an external ID configured but it is not provided in the output configuration Bitmovin won't be able to write to the S3 bucket. Also if the external ID does not match the one configured for the IAM role on AWS side, Bitmovin won't be able to access the S3 bucket.  If you need to change the external ID that is used by your IAM role, you need to create a new output, and use the external ID provided by the API to update your IAM role.  For more information please visit https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html 

        :param external_id: The external_id of this S3RoleBasedOutput.
        :type: string_types
        """

        if external_id is not None:
            if not isinstance(external_id, string_types):
                raise TypeError("Invalid type for `external_id`, type has to be `string_types`")

        self._external_id = external_id

    @property
    def external_id_mode(self):
        # type: () -> ExternalIdMode
        """Gets the external_id_mode of this S3RoleBasedOutput.


        :return: The external_id_mode of this S3RoleBasedOutput.
        :rtype: ExternalIdMode
        """
        return self._external_id_mode

    @external_id_mode.setter
    def external_id_mode(self, external_id_mode):
        # type: (ExternalIdMode) -> None
        """Sets the external_id_mode of this S3RoleBasedOutput.


        :param external_id_mode: The external_id_mode of this S3RoleBasedOutput.
        :type: ExternalIdMode
        """

        if external_id_mode is not None:
            if not isinstance(external_id_mode, ExternalIdMode):
                raise TypeError("Invalid type for `external_id_mode`, type has to be `ExternalIdMode`")

        self._external_id_mode = external_id_mode

    @property
    def md5_meta_tag(self):
        # type: () -> string_types
        """Gets the md5_meta_tag of this S3RoleBasedOutput.

        If set a user defined tag (x-amz-meta-) with that key will be used to store the MD5 hash of the file.

        :return: The md5_meta_tag of this S3RoleBasedOutput.
        :rtype: string_types
        """
        return self._md5_meta_tag

    @md5_meta_tag.setter
    def md5_meta_tag(self, md5_meta_tag):
        # type: (string_types) -> None
        """Sets the md5_meta_tag of this S3RoleBasedOutput.

        If set a user defined tag (x-amz-meta-) with that key will be used to store the MD5 hash of the file.

        :param md5_meta_tag: The md5_meta_tag of this S3RoleBasedOutput.
        :type: string_types
        """

        if md5_meta_tag is not None:
            if not isinstance(md5_meta_tag, string_types):
                raise TypeError("Invalid type for `md5_meta_tag`, type has to be `string_types`")

        self._md5_meta_tag = md5_meta_tag

    @property
    def cloud_region(self):
        # type: () -> AwsCloudRegion
        """Gets the cloud_region of this S3RoleBasedOutput.


        :return: The cloud_region of this S3RoleBasedOutput.
        :rtype: AwsCloudRegion
        """
        return self._cloud_region

    @cloud_region.setter
    def cloud_region(self, cloud_region):
        # type: (AwsCloudRegion) -> None
        """Sets the cloud_region of this S3RoleBasedOutput.


        :param cloud_region: The cloud_region of this S3RoleBasedOutput.
        :type: AwsCloudRegion
        """

        if cloud_region is not None:
            if not isinstance(cloud_region, AwsCloudRegion):
                raise TypeError("Invalid type for `cloud_region`, type has to be `AwsCloudRegion`")

        self._cloud_region = cloud_region

    @property
    def signature_version(self):
        # type: () -> S3SignatureVersion
        """Gets the signature_version of this S3RoleBasedOutput.

        Specifies the method used for authentication

        :return: The signature_version of this S3RoleBasedOutput.
        :rtype: S3SignatureVersion
        """
        return self._signature_version

    @signature_version.setter
    def signature_version(self, signature_version):
        # type: (S3SignatureVersion) -> None
        """Sets the signature_version of this S3RoleBasedOutput.

        Specifies the method used for authentication

        :param signature_version: The signature_version of this S3RoleBasedOutput.
        :type: S3SignatureVersion
        """

        if signature_version is not None:
            if not isinstance(signature_version, S3SignatureVersion):
                raise TypeError("Invalid type for `signature_version`, type has to be `S3SignatureVersion`")

        self._signature_version = signature_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(S3RoleBasedOutput, self), "to_dict"):
            result = super(S3RoleBasedOutput, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, S3RoleBasedOutput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.analytics_s3_role_based_output import AnalyticsS3RoleBasedOutput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.s3_role_based_output import S3RoleBasedOutput
from bitmovin_api_sdk.analytics.outputs.s3_role_based.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.analytics.outputs.s3_role_based.analytics_s3_role_based_output_list_query_params import AnalyticsS3RoleBasedOutputListQueryParams


class S3RoleBasedApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(S3RoleBasedApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, analytics_s3_role_based_output, **kwargs):
        # type: (AnalyticsS3RoleBasedOutput, dict) -> AnalyticsS3RoleBasedOutput
        """Create S3 Role-based Output

        :param analytics_s3_role_based_output: The S3 Role-based output to be created
        :type analytics_s3_role_based_output: AnalyticsS3RoleBasedOutput, required
        :return: S3 Role-based Output
        :rtype: AnalyticsS3RoleBasedOutput
        """

        return self.api_client.post(
            '/analytics/outputs/s3-role-based',
            analytics_s3_role_based_output,
            type=AnalyticsS3RoleBasedOutput,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> S3RoleBasedOutput
        """Delete S3 Role-based Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the input
        :rtype: S3RoleBasedOutput
        """

        return self.api_client.delete(
            '/analytics/outputs/s3-role-based/{output_id}',
            path_params={'output_id': output_id},
            type=S3RoleBasedOutput,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> S3RoleBasedOutput
        """S3 Role-based Output Details

        :param output_id: Id of the input
        :type output_id: string_types, required
        :return: S3 Role-based Output
        :rtype: S3RoleBasedOutput
        """

        return self.api_client.get(
            '/analytics/outputs/s3-role-based/{output_id}',
            path_params={'output_id': output_id},
            type=S3RoleBasedOutput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (AnalyticsS3RoleBasedOutputListQueryParams, dict) -> AnalyticsS3RoleBasedOutput
        """List S3 Role-based Outputs

        :param query_params: Query parameters
        :type query_params: AnalyticsS3RoleBasedOutputListQueryParams
        :return: List of S3 Role-based Outputs
        :rtype: AnalyticsS3RoleBasedOutput
        """

        return self.api_client.get(
            '/analytics/outputs/s3-role-based',
            query_params=query_params,
            pagination_response=True,
            type=AnalyticsS3RoleBasedOutput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.broadcast_ts_program_configuration import BroadcastTsProgramConfiguration
from bitmovin_api_sdk.models.broadcast_ts_transport_configuration import BroadcastTsTransportConfiguration
import pprint
import six


class BroadcastTsMuxingConfiguration(object):
    @poscheck_model
    def __init__(self,
                 transport=None,
                 program=None,
                 video_streams=None,
                 audio_streams=None,
                 subtitle_streams=None):
        # type: (BroadcastTsTransportConfiguration, BroadcastTsProgramConfiguration, list[BroadcastTsVideoInputStreamConfiguration], list[BroadcastTsAudioInputStreamConfiguration], list[BroadcastTsSubtitleInputStreamConfiguration]) -> None

        self._transport = None
        self._program = None
        self._video_streams = list()
        self._audio_streams = list()
        self._subtitle_streams = list()
        self.discriminator = None

        if transport is not None:
            self.transport = transport
        if program is not None:
            self.program = program
        if video_streams is not None:
            self.video_streams = video_streams
        if audio_streams is not None:
            self.audio_streams = audio_streams
        if subtitle_streams is not None:
            self.subtitle_streams = subtitle_streams

    @property
    def openapi_types(self):
        types = {
            'transport': 'BroadcastTsTransportConfiguration',
            'program': 'BroadcastTsProgramConfiguration',
            'video_streams': 'list[BroadcastTsVideoInputStreamConfiguration]',
            'audio_streams': 'list[BroadcastTsAudioInputStreamConfiguration]',
            'subtitle_streams': 'list[BroadcastTsSubtitleInputStreamConfiguration]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'transport': 'transport',
            'program': 'program',
            'video_streams': 'videoStreams',
            'audio_streams': 'audioStreams',
            'subtitle_streams': 'subtitleStreams'
        }
        return attributes

    @property
    def transport(self):
        # type: () -> BroadcastTsTransportConfiguration
        """Gets the transport of this BroadcastTsMuxingConfiguration.

        Transport configuration details for the Broadcast TS muxing.

        :return: The transport of this BroadcastTsMuxingConfiguration.
        :rtype: BroadcastTsTransportConfiguration
        """
        return self._transport

    @transport.setter
    def transport(self, transport):
        # type: (BroadcastTsTransportConfiguration) -> None
        """Sets the transport of this BroadcastTsMuxingConfiguration.

        Transport configuration details for the Broadcast TS muxing.

        :param transport: The transport of this BroadcastTsMuxingConfiguration.
        :type: BroadcastTsTransportConfiguration
        """

        if transport is not None:
            if not isinstance(transport, BroadcastTsTransportConfiguration):
                raise TypeError("Invalid type for `transport`, type has to be `BroadcastTsTransportConfiguration`")

        self._transport = transport

    @property
    def program(self):
        # type: () -> BroadcastTsProgramConfiguration
        """Gets the program of this BroadcastTsMuxingConfiguration.

        Program configuration details for the Broadcast TS muxing.

        :return: The program of this BroadcastTsMuxingConfiguration.
        :rtype: BroadcastTsProgramConfiguration
        """
        return self._program

    @program.setter
    def program(self, program):
        # type: (BroadcastTsProgramConfiguration) -> None
        """Sets the program of this BroadcastTsMuxingConfiguration.

        Program configuration details for the Broadcast TS muxing.

        :param program: The program of this BroadcastTsMuxingConfiguration.
        :type: BroadcastTsProgramConfiguration
        """

        if program is not None:
            if not isinstance(program, BroadcastTsProgramConfiguration):
                raise TypeError("Invalid type for `program`, type has to be `BroadcastTsProgramConfiguration`")

        self._program = program

    @property
    def video_streams(self):
        # type: () -> list[BroadcastTsVideoInputStreamConfiguration]
        """Gets the video_streams of this BroadcastTsMuxingConfiguration.


        :return: The video_streams of this BroadcastTsMuxingConfiguration.
        :rtype: list[BroadcastTsVideoInputStreamConfiguration]
        """
        return self._video_streams

    @video_streams.setter
    def video_streams(self, video_streams):
        # type: (list) -> None
        """Sets the video_streams of this BroadcastTsMuxingConfiguration.


        :param video_streams: The video_streams of this BroadcastTsMuxingConfiguration.
        :type: list[BroadcastTsVideoInputStreamConfiguration]
        """

        if video_streams is not None:
            if not isinstance(video_streams, list):
                raise TypeError("Invalid type for `video_streams`, type has to be `list[BroadcastTsVideoInputStreamConfiguration]`")

        self._video_streams = video_streams

    @property
    def audio_streams(self):
        # type: () -> list[BroadcastTsAudioInputStreamConfiguration]
        """Gets the audio_streams of this BroadcastTsMuxingConfiguration.


        :return: The audio_streams of this BroadcastTsMuxingConfiguration.
        :rtype: list[BroadcastTsAudioInputStreamConfiguration]
        """
        return self._audio_streams

    @audio_streams.setter
    def audio_streams(self, audio_streams):
        # type: (list) -> None
        """Sets the audio_streams of this BroadcastTsMuxingConfiguration.


        :param audio_streams: The audio_streams of this BroadcastTsMuxingConfiguration.
        :type: list[BroadcastTsAudioInputStreamConfiguration]
        """

        if audio_streams is not None:
            if not isinstance(audio_streams, list):
                raise TypeError("Invalid type for `audio_streams`, type has to be `list[BroadcastTsAudioInputStreamConfiguration]`")

        self._audio_streams = audio_streams

    @property
    def subtitle_streams(self):
        # type: () -> list[BroadcastTsSubtitleInputStreamConfiguration]
        """Gets the subtitle_streams of this BroadcastTsMuxingConfiguration.


        :return: The subtitle_streams of this BroadcastTsMuxingConfiguration.
        :rtype: list[BroadcastTsSubtitleInputStreamConfiguration]
        """
        return self._subtitle_streams

    @subtitle_streams.setter
    def subtitle_streams(self, subtitle_streams):
        # type: (list) -> None
        """Sets the subtitle_streams of this BroadcastTsMuxingConfiguration.


        :param subtitle_streams: The subtitle_streams of this BroadcastTsMuxingConfiguration.
        :type: list[BroadcastTsSubtitleInputStreamConfiguration]
        """

        if subtitle_streams is not None:
            if not isinstance(subtitle_streams, list):
                raise TypeError("Invalid type for `subtitle_streams`, type has to be `list[BroadcastTsSubtitleInputStreamConfiguration]`")

        self._subtitle_streams = subtitle_streams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BroadcastTsMuxingConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.primetime.primetime_api import PrimetimeApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.primetime.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.fmp4.drm.primetime.prime_time_drm_list_query_params import PrimeTimeDrmListQueryParams
